@@ -79,6 +79,14 @@ def xl_rowcol_to_cell(row_num, col_num):
     return col_str + str(row_num)
 
 
+def get_sheet_all_range(sheet):
+    max_row, max_col = (
+        sheet._properties["gridProperties"]["rowCount"],
+        sheet._properties["gridProperties"]["columnCount"],
+    )
+    return f"{xl_rowcol_to_cell(0,0)}:{xl_rowcol_to_cell(max_row, max_col)}"
+
+
 def _create_gsheet_table_aux(
     mix: FixedVolumeMix, add_total_line=True, columns_default_unit=True
 ):
@@ -229,6 +237,7 @@ def create_targets(
     row_spacing=1,
     empty_desc="empty",
     print_mixes=False,
+    font_size=10,
 ):
 
     if layout_range != "A1:M9":
@@ -241,6 +250,14 @@ def create_targets(
     except gspread.WorksheetNotFound as e:
         targets_sheet = workbook.add_worksheet("Targets", rows=100, cols=100)
     targets_sheet = reset_sheet(workbook, targets_sheet)
+    targets_sheet.format(
+        get_sheet_all_range(targets_sheet),
+        {
+            "textFormat": {
+                "fontSize": font_size,
+            },
+        },
+    )
 
     layout = extract_layout_from_layout_sheet(layout_sheet, layout_range=layout_range)
 
